@@ -17,8 +17,8 @@
 //
 // Alternative licensing terms are available from the licensor.
 // For commercial licensing, see <https://www.artifex.com/> or contact
-// Artifex Software, Inc., 1305 Grant Avenue - Suite 200, Novato,
-// CA 94945, U.S.A., +1(415)492-9861, for further information.
+// Artifex Software, Inc., 39 Mesa Street, Suite 108A, San Francisco,
+// CA 94129, USA, for further information.
 
 /*
  * Information tool.
@@ -229,6 +229,7 @@ gatherdimensions(fz_context *ctx, globals *glo, int page, pdf_obj *pageref)
 {
 	fz_rect bbox;
 	pdf_obj *obj;
+	float unit;
 	int j;
 
 	obj = pdf_dict_get(ctx, pageref, PDF_NAME(MediaBox));
@@ -237,15 +238,11 @@ gatherdimensions(fz_context *ctx, globals *glo, int page, pdf_obj *pageref)
 
 	bbox = pdf_to_rect(ctx, obj);
 
-	obj = pdf_dict_get(ctx, pageref, PDF_NAME(UserUnit));
-	if (pdf_is_number(ctx, obj))
-	{
-		float unit = pdf_to_real(ctx, obj);
-		bbox.x0 *= unit;
-		bbox.y0 *= unit;
-		bbox.x1 *= unit;
-		bbox.y1 *= unit;
-	}
+	unit = pdf_dict_get_real_default(ctx, pageref, PDF_NAME(UserUnit), 1);
+	bbox.x0 *= unit;
+	bbox.y0 *= unit;
+	bbox.x1 *= unit;
+	bbox.y1 *= unit;
 
 	for (j = 0; j < glo->dims; j++)
 		if (!memcmp(glo->dim[j].u.dim.bbox, &bbox, sizeof (fz_rect)))
@@ -596,26 +593,28 @@ gatherpatterns(fz_context *ctx, globals *glo, int page, pdf_obj *pageref, pdf_ob
 }
 
 static void
-gatherresourceinfo(fz_context *ctx, pdf_mark_list *mark_list, globals *glo, int page, pdf_obj *rsrc, int show)
+gatherresourceinfo(fz_context *ctx, pdf_mark_list *mark_list, globals *glo, int page, pdf_obj *obj, int show)
 {
+	pdf_obj *rsrc;
 	pdf_obj *pageref;
 	pdf_obj *font;
 	pdf_obj *xobj;
 	pdf_obj *shade;
 	pdf_obj *pattern;
-	pdf_obj *subrsrc;
 	int i;
 
+	/* stop on cyclic resource dependencies */
+	if (pdf_mark_list_push(ctx, mark_list, obj))
+		return;
+
+	rsrc = pdf_dict_get(ctx, obj, PDF_NAME(Resources));
+
 	pageref = pdf_lookup_page_obj(ctx, glo->doc, page-1);
 	if (!pageref)
 		fz_throw(ctx, FZ_ERROR_GENERIC, "cannot retrieve info from page %d", page);
 
-	/* stop on cyclic resource dependencies */
-	if (pdf_mark_list_push(ctx, mark_list, rsrc))
-		return;
-
 	font = pdf_dict_get(ctx, rsrc, PDF_NAME(Font));
-	if (show & FONTS && font)
+	if (show & FONTS && font && !pdf_mark_list_push(ctx, mark_list, font))
 	{
 		int n;
 
@@ -623,16 +622,12 @@ gatherresourceinfo(fz_context *ctx, pdf_mark_list *mark_list, globals *glo, int
 		n = pdf_dict_len(ctx, font);
 		for (i = 0; i < n; i++)
 		{
-			pdf_obj *obj = pdf_dict_get_val(ctx, font, i);
-
-			subrsrc = pdf_dict_get(ctx, obj, PDF_NAME(Resources));
-			if (subrsrc && pdf_objcmp(ctx, rsrc, subrsrc))
-				gatherresourceinfo(ctx, mark_list, glo, page, subrsrc, show);
+			gatherresourceinfo(ctx, mark_list, glo, page, pdf_dict_get_val(ctx, font, i), show);
 		}
 	}
 
 	xobj = pdf_dict_get(ctx, rsrc, PDF_NAME(XObject));
-	if (show & (IMAGES|XOBJS) && xobj)
+	if (show & (IMAGES|XOBJS) && xobj && !pdf_mark_list_push(ctx, mark_list, xobj))
 	{
 		int n;
 
@@ -646,29 +641,23 @@ gatherresourceinfo(fz_context *ctx, pdf_mark_list *mark_list, globals *glo, int
 		n = pdf_dict_len(ctx, xobj);
 		for (i = 0; i < n; i++)
 		{
-			pdf_obj *obj = pdf_dict_get_val(ctx, xobj, i);
-			subrsrc = pdf_dict_get(ctx, obj, PDF_NAME(Resources));
-			if (subrsrc && pdf_objcmp(ctx, rsrc, subrsrc))
-				gatherresourceinfo(ctx, mark_list, glo, page, subrsrc, show);
+			gatherresourceinfo(ctx, mark_list, glo, page, pdf_dict_get_val(ctx, xobj, i), show);
 		}
 	}
 
 	shade = pdf_dict_get(ctx, rsrc, PDF_NAME(Shading));
-	if (show & SHADINGS && shade)
+	if (show & SHADINGS && shade && !pdf_mark_list_push(ctx, mark_list, shade))
 		gathershadings(ctx, glo, page, pageref, shade);
 
 	pattern = pdf_dict_get(ctx, rsrc, PDF_NAME(Pattern));
-	if (show & PATTERNS && pattern)
+	if (show & PATTERNS && pattern && !pdf_mark_list_push(ctx, mark_list, pattern))
 	{
 		int n;
 		gatherpatterns(ctx, glo, page, pageref, pattern);
 		n = pdf_dict_len(ctx, pattern);
 		for (i = 0; i < n; i++)
 		{
-			pdf_obj *obj = pdf_dict_get_val(ctx, pattern, i);
-			subrsrc = pdf_dict_get(ctx, obj, PDF_NAME(Resources));
-			if (subrsrc && pdf_objcmp(ctx, rsrc, subrsrc))
-				gatherresourceinfo(ctx, mark_list, glo, page, subrsrc, show);
+			gatherresourceinfo(ctx, mark_list, glo, page, pdf_dict_get_val(ctx, pattern, i), show);
 		}
 	}
 }
@@ -678,7 +667,6 @@ gatherpageinfo(fz_context *ctx, globals *glo, int page, int show)
 {
 	pdf_mark_list mark_list;
 	pdf_obj *pageref;
-	pdf_obj *rsrc;
 
 	pageref = pdf_lookup_page_obj(ctx, glo->doc, page-1);
 
@@ -689,10 +677,7 @@ gatherpageinfo(fz_context *ctx, globals *glo, int page, int show)
 
 	pdf_mark_list_init(ctx, &mark_list);
 	fz_try(ctx)
-	{
-		rsrc = pdf_dict_get(ctx, pageref, PDF_NAME(Resources));
-		gatherresourceinfo(ctx, &mark_list, glo, page, rsrc, show);
-	}
+		gatherresourceinfo(ctx, &mark_list, glo, page, pageref, show);
 	fz_always(ctx)
 		pdf_mark_list_free(ctx, &mark_list);
 	fz_catch(ctx)
@@ -1004,7 +989,7 @@ pdfinfo_info(fz_context *ctx, fz_output *out, char *filename, char *password, in
 				glo.doc = pdf_open_document(glo.ctx, filename);
 				if (pdf_needs_password(ctx, glo.doc))
 					if (!pdf_authenticate_password(ctx, glo.doc, password))
-						fz_throw(glo.ctx, FZ_ERROR_GENERIC, "cannot authenticate password: %s", filename);
+						fz_throw(glo.ctx, FZ_ERROR_ARGUMENT, "cannot authenticate password: %s", filename);
 				glo.pagecount = pdf_count_pages(ctx, glo.doc);
 
 				showglobalinfo(ctx, &glo);
@@ -1071,7 +1056,10 @@ int pdfinfo_main(int argc, char **argv)
 	fz_try(ctx)
 		pdfinfo_info(ctx, fz_stdout(ctx), filename, password, show, &argv[fz_optind], argc-fz_optind);
 	fz_catch(ctx)
+	{
+		fz_report_error(ctx);
 		ret = 1;
+	}
 	fz_drop_context(ctx);
 	return ret;
 }
