@@ -522,13 +522,18 @@ static const char *xps_mimetypes[] =
 };
 
 static int
-xps_recognize_doc_content(fz_context *ctx, fz_stream *stream, fz_archive *dir)
+xps_recognize_doc_content(fz_context *ctx, const fz_document_handler *handler, fz_stream *stream, fz_archive *dir, void **state, fz_document_recognize_state_free_fn **free_state)
 {
 	fz_archive *arch = NULL;
 	int ret = 0;
 	fz_xml *xml = NULL;
 	fz_xml *pos;
 
+	if (state)
+		*state = NULL;
+	if (free_state)
+		*free_state = NULL;
+
 	fz_var(arch);
 	fz_var(ret);
 	fz_var(xml);
@@ -567,7 +572,7 @@ xps_recognize_doc_content(fz_context *ctx, fz_stream *stream, fz_archive *dir)
 }
 
 static fz_document *
-xps_open(fz_context *ctx, fz_stream *file, fz_stream *accel, fz_archive *dir)
+xps_open(fz_context *ctx, const fz_document_handler *handler, fz_stream *file, fz_stream *accel, fz_archive *dir, void *state)
 {
 	if (file)
 		return xps_open_document_with_stream(ctx, file);
